@@ -66,13 +66,18 @@ class Application(object):
         environment variable ``TOOL_CONF``. If it is empty too, empty
         configuration is taken.
 
+    :param extra_settings:
+
+        merged into `settings`; nested dictionaries are updated instead of
+        being replaced as it would happen with ``dict.update()``.
+
     Usage::
 
         #!/usr/bin/env python
 
         from tool import Application
 
-        app = Application('conf.yaml')
+        app = Application('conf.yaml', 'local.yaml')
 
         if __name__=='__main__':
             app.dispatch()    # process sys.argv and call a command
@@ -93,9 +98,9 @@ class Application(object):
     #  Magic methods  |
     #-----------------+
 
-    def __init__(self, settings=None):   #, url_map=None):
+    def __init__(self, settings=None, extra_settings=None):   #, url_map=None):
         self.cli_parser = cli.ArghParser()
-        self.settings = self._prepare_settings(settings)
+        self.settings = self._prepare_settings(settings, extra_settings)
         self._register()
         self._setup_logging()
         self._load_extensions()
@@ -117,17 +122,22 @@ class Application(object):
                      '{0}...'.format(local))
         local.app_manager = self
 
-    def _prepare_settings(self, settings):
+    def _prepare_settings(self, settings, extra):
         logger.debug('Preparing settings...')
-        if settings is None:
-            settings = os.environ.get('TOOL_CONF', None)
-            if not settings:
+        basic_dict = self._prepare_settings_dict(settings)
+        extra_dict = self._prepare_settings_dict(extra)
+        return conf.merge_dicts(basic_dict, extra_dict)
+
+    def _prepare_settings_dict(self, value):
+        if value is None:
+            value = os.environ.get('TOOL_CONF', None)
+            if not value:
                 return {}
-        if isinstance(settings, dict):
-            return settings
-        if isinstance(settings, basestring):
-            return conf.load(settings)
-        raise TypeError('expected None, dict or string, got %s' % settings)
+        if isinstance(value, dict):
+            return value
+        if isinstance(value, basestring):
+            return conf.load(value)
+        raise TypeError('expected None, dict or string, got %s' % value)
 
     def _setup_logging(self):
         conf = self.settings.get('logging')
