@@ -12,7 +12,6 @@ String utilities
 
 __all__ = ['slugify', 'slugify_i18n']
 
-from tool import dist
 import re
 try:
     from unidecode import unidecode
@@ -48,7 +47,6 @@ def slugify_i18n(value):
         u'foo-privet-123'
 
     """
-    dist.check_dependencies(__name__, 'slugify_i18n')
     if unidecode is None:  # pragma: nocover
         raise ImportError('Could not load library "unidecode".')
     return _slugify_simple(unidecode(value))
